/*
    Copyright (C) 2022 Tenable, Inc.

	Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

		http://www.apache.org/licenses/LICENSE-2.0

	Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/

package config

import (
	"github.com/awslabs/goformation/v6/cloudformation/ecs"
	"github.com/tenable/terrascan/pkg/mapper/iac-providers/cft/functions"
)

// EcsServiceConfig holds config for aws_ecs_service
type EcsServiceConfig struct {
	Config
	IamRole string `json:"iam_role"`
}

// GetEcsServiceConfig returns config for aws_ecs_service
func GetEcsServiceConfig(c *ecs.Service) []AWSResourceConfig {
	cf := EcsServiceConfig{
		Config: Config{
			Name: functions.GetVal(c.ServiceName),
			Tags: c.Tags,
		},
		IamRole: functions.GetVal(c.Role),
	}
	return []AWSResourceConfig{{
		Resource: cf,
		Metadata: c.AWSCloudFormationMetadata,
	}}
}
